<?php

namespace Cli\Commands;

use Cli\Assets\Console;

abstract class Command
{
    use Console;

    /**
     * @var string
     */
    public $signature = '';

    /**
     * @var string
     */
    public $description = '';

    /**
     * @var array
     */
    private $args = [];

    /*
     * @return mixed
     */
    abstract public function handle();

    /**
     * Command constructor.
     */
    public function __construct()
    {
        $this->args = $this->getArgs();
    }

    /**
     * @return array
     */
    private function getArgs()
    {
        global $argv;

        $args = [];
        for ($i = 1; $i < count($argv); $i++) {
            if (preg_match('/^--([^=]+)=(.*)/', $argv[$i], $match)) {
                $args[$match[1]] = $match[2];
            }
        }

        return $args;
    }

    /**
     * @param $name
     * @return string
     */
    public function argument($name)
    {
        if(!isset($this->args[$name])) return '';

        return $this->args[$name];
    }

    /**
     * @return string
     */
    public function getName()
    {
        return $this->signature;
    }

    /**
     * @return string
     */
    public function getDescription()
    {
        return $this->description;
    }

}