<?php

namespace Runtime\Config;

use Dotenv\Dotenv;

class Env {

    /**
     * @param string $key
     * @return string
     */
    public static function get(string $key)
    {
        $dotenv = Dotenv::createImmutable('../');
        $dotenv->load();

        return self::filter($dotenv, $key);
    }

    /**
     * @param Dotenv $dotenv
     * @param string $key
     * @return mixed
     */
    private static function filter($dotenv, string $key)
    {
        $key = strtoupper($key);
        if (!$dotenv->ifPresent($key)) return false;

        $result = getenv($key);

        if($dotenv->required($key)->isBoolean()) {
            return filter_var($result, FILTER_VALIDATE_BOOLEAN);
        }
        else if($dotenv->required($key)->isInteger()) {
            return (int) $result;
        }
        else {
            return $result;
        }
    }

}