<?php

namespace Runtime\Exceptions;

use Whoops\Handler\Handler;
use Whoops\Handler\JsonResponseHandler;
use Whoops\Handler\PlainTextHandler;
use Whoops\Run as RunWhoops;
use Whoops\Handler\PrettyPageHandler;
use Whoops\Util\Misc;
use function DI\value;

class ExceptionHandler {

    /**
     * @var RunWhoops
     */
    private static $handler;

    /**
     * @param null $abstract
     * @param null $message
     */
    public static function make($abstract = null, $message = null)
    {
        if(is_string($abstract)) {
            $abstract = app()->make($abstract, $message);
        }

        if(is_subclass_of($abstract, 'Exception')) {
            self::$handler->handleException($abstract);
        }

        die();
    }

    /**
     * Register Whoops (Error handler)
     */
    public static function register()
    {
        self::$handler = new RunWhoops();

        $debug = env('debug');

        if($debug === false) {
            self::$handler->pushHandler(function() {
                if(app()->view()->exist('errors.500')) {
                    echo app()->view()->render('errors.500');
                }
                return Handler::DONE;
            });
        }
        else {
            self::$handler->pushHandler(self::handler());
        }

        self::$handler->register();
    }

    /**
     * @return Handler
     */
    private static function handler()
    {
        if (Misc::isAjaxRequest()){
            return new JsonResponseHandler();
        }

        if (Misc::isCommandLine()){
            return new PlainTextHandler();
        }

        return new PrettyPageHandler();
    }

}

